management-app
A simple application that implements management operations, such as firmware upgrade.
It directly implements the APDU and CTAPHID dispatch App interfaces.
Modules
Structs
Enums
Traits
- Client
- Config
- Status
Bytes - Trait indicating that a value can be used as a status