pub enum ResetConfigResult {
Changed,
Unchanged,
WrongKey,
}Variants
Changed
The config was changed as a result of the reset to default
Unchanged
The config was at the default value
WrongKey
The key does not correspond to any application that can be reset
Implementations
Sourceimpl ResetConfigResult
impl ResetConfigResult
pub fn is_changed(&self) -> bool
pub fn is_unchanged(&self) -> bool
pub fn is_error(&self) -> bool