#[repr(u8)]pub enum ResetSignal {
None = 0,
FactoryReset = 1,
ConfigChanged = 2,
}Variants
None = 0
The App can continue operating
FactoryReset = 1
The app has had it state factory reseted by the admin app
It should delete any runtime state it is currently holding, then acknowledge the reset and continue working.
ConfigChanged = 2
A configuration relevant to the application has been changed.
The application must reject all incoming request and store no persistent state until a power cycle.
Implementations
Sourceimpl ResetSignal
impl ResetSignal