pub struct Migrator {
pub migrate: fn(&dyn DynFilesystem, &dyn DynFilesystem) -> Result<(), Error>,
pub version: u32,
}Fields
migrate: fn(&dyn DynFilesystem, &dyn DynFilesystem) -> Result<(), Error>The function performing the migration
First argument is the Internal Filesystem, second argument is the External
version: u32The version of the storage for which the migration needs to be run