Crate admin_app

Crate admin_app 

management-app

A simple application that implements management operations, such as firmware upgrade.

It directly implements the APDU and CTAPHID dispatch App interfaces.

Modules

migrations

Structs

App
ConfigField
ResetSignalAllocation
Structure meant to be stored in a static to signal applications that they have been factory-resetted by the admin app

Enums

ConfigError
ConfigValueMut
FieldType
ResetConfigResult
ResetSignal

Traits

Client
Config
Reboot
StatusBytes
Trait indicating that a value can be used as a status