management-app
A simple application that implements management operations, such as firmware upgrade.
It directly implements the APDU and CTAPHID dispatch App interfaces.
Modules
Structs
- App
- Config
Field - Reset
Signal Allocation - Structure meant to be stored in a
staticto signal applications that they have been factory-resetted by the admin app
Enums
Traits
- Client
- Config
- Reboot
- Status
Bytes - Trait indicating that a value can be used as a status