pub struct App<T, S, C = ()> { /* private fields */ }Implementations
Sourceimpl<T, S, C> App<T, S, C>
impl<T, S, C> App<T, S, C>
Sourcepub fn load_config<F: Filestore>(
client: T,
filestore: &mut F,
data: Data,
status: S,
) -> Result<Self, (T, ConfigError)>
pub fn load_config<F: Filestore>( client: T, filestore: &mut F, data: Data, status: S, ) -> Result<Self, (T, ConfigError)>
Create an admin app instance, loading the configuration from the filesystem.
pub fn migrate<F: Filestore>( &mut self, to_version: u32, store: impl Store, filestore: &mut F, ) -> Result<(), ConfigError>
Sourcepub fn with_default_config(client: T, data: Data, status: S) -> Self
pub fn with_default_config(client: T, data: Data, status: S) -> Self
Create an admin app instance without the configuration mechanism, using the default config values.
This is only intended for debugging, testing and example code. In production,
App::load_config should be used.
pub fn config(&self) -> &C
pub fn config_mut(&mut self) -> &mut C
pub fn save_config_filestore<F: Filestore>( &mut self, filestore: &mut F, ) -> Result<(), ConfigError>
pub fn status(&self) -> &S
pub fn status_mut(&mut self) -> &mut S