pub struct Data {
pub uuid: [u8; 16],
pub version: u32,
pub full_version: &'static str,
pub migrations: &'static [Migrator],
pub reboot: fn() -> !,
pub reboot_to_firmware_update: fn(),
pub reboot_to_firmware_update_destructive: Option<fn() -> !>,
pub locked: fn() -> bool,
}Fields
uuid: [u8; 16]version: u32full_version: &'static strmigrations: &'static [Migrator]reboot: fn() -> !Reboots the device.
reboot_to_firmware_update: fn()Reboots the device.
Presuming the device has a separate mode of operation that allows updating its firmware (for instance, a bootloader), reboots the device into this mode.
reboot_to_firmware_update_destructive: Option<fn() -> !>Reboots the device.
Presuming the device has a separate destructive but more reliable way of rebooting into the firmware mode of operation, does so.
locked: fn() -> boolIs device bootloader locked down? E.g., is secure boot enabled?